/*
# PostgreSQL Database Modeler (pgModeler)
#
# Copyright 2006-2019 - Raphael Araújo e Silva <raphael@pgmodeler.io>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation version 3.
#
# This program is distributed in the hope that it will be useful),
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# The complete text of GPLv3 is at LICENSE file on source code root directory.
# Also), you can get the complete GNU General Public License at <http://www.gnu.org/licenses/>
*/

/**
\ingroup libparsers
\namespace Attributes
\brief Definition of parsers attributes namespace which stores a series of static strings constants used
 to reference the attributes of objects in SQL/XML generation methods.
 Each string stores the name of the attribute used in the schema file "sch" of the respective objects.
\note <strong>Creation date:</strong> 23/09/2008
*/

#ifndef ATTRIBUTES_H
#define ATTRIBUTES_H

/* Including QByteArray due to 'QByteArray has no toStdString()'
   error on Qt 5.4 (Windows only) */
#include <QByteArray>
#include <QString>

namespace Attributes {
	extern const QString
	False,
	File,
	LcCollate,
	LcCtype,
	True,
	ActiveLayers,
	AdminOption,
	AdminRoles,
	Alias,
	Alignment,
	AlignObjsToGrid,
	AlterCmds,
	AllowConns,
	AnalyzeFunc,
	AncestorTable,
	AppendAtEod,
	AppendedSql,
	Application,
	ArgCount,
	ArgDefCount,
	ArgDefaults,
	ArgModes,
	ArgNames,
	ArgTypes,
	Arguments,
	AscOrder,
	Assignment,
	Attribute,
	AttribsPage,
	AttribsPerPage,
	AutoBrowseDb,
	AutoSaveInterval,
	BackgroundColor,
	BaseType,
	Before,
	BehaviorType,
	Bold,
	BorderColor,
	Bottom,
	Buffering,
	ByValue,
	BypassRls,
	Cache,
	CanonicalFunc,
	CanvasCornerMove,
	Cascade,
	CaseSensitive,
	CastType,
	Category,
	Change,
	Changelog,
	CheckExp,
	CheckUpdate,
	CkConstr,
	ClientEncoding,
	CodeCompletion,
	CodeFontSize,
	CodeFont,
	CodeTabWidth,
	ColIndexes,
	CollapseMode,
	Collatable,
	Collation,
	Collations,
	Color,
	Colors,
	ColsComment,
	ColIsIdentity,
	ColumnAlias,
	Column,
	Columns,
	Command,
	Commands,
	Comment,
	CommutatorOp,
	ComparisonType,
	CompactView,
	CompletionTrigger,
	CompositeType,
	Concurrent,
	Condition,
	Configuration,
	ConfigFile,
	ConfirmValidation,
	ConnLimit,
	ConnectCenterPnts,
	ConnectFkToPk,
	ConnectTableEdges,
	ConnectPriv,
	Connection,
	Connections,
	ConnectionTimeout,
	ConstrDefs,
	ConstrIndexes,
	ConstrSqlDisabled,
	Constraint,
	Constraints,
	Contents,
	CopyMode,
	CopyOptions,
	CopyTable,
	CreateCmds,
	CreatePriv,
	Create,
	CreateDb,
	CreateRole,
	CrowsFoot,
	CteExpression,
	CurVersion,
	CurIdentityType,
	CustomColor,
	CustomFilter,
	CustomIdxs,
	Cycle,
	Database,
	DataDirectory,
	Date,
	DbModel,
	DdlEndToken,
	DeadRowsAmount,
	DeclInTable,
	Declaration,
	DefaultCollation,
	DefaultForOps,
	DefaultOwner,
	DefaultSchema,
	DefaultTablespace,
	DefaultValue,
	Default,
	DeferType,
	Deferrable,
	Definition,
	DelAction,
	DelEvent,
	DeletePriv,
	Delimiter,
	DestType,
	DstType,
	Diff,
	Dimension,
	Directory,
	DisableSmoothness,
	DisplayLineNumbers,
	DomConstraint,
	DockWidgets,
	DropCmds,
	Drop,
	DstColPattern,
	DstColumns,
	DstEncoding,
	DstFkPattern,
	DstLabel,
	DstRequired,
	DstTable,
	DynamicLibraryPath,
	DynamicSharedMemory,
	Element,
	Elements,
	Encoding,
	Encrypted,
	EndExp,
	EnumType,
	Enumerations,
	EventType,
	Event,
	Events,
	ExConstr,
	ExactMatch,
	ExcBuiltinArrays,
	ExcludeElement,
	ExecType,
	ExecutPriv,
	ExecutionCost,
	ExistingValue,
	Explicit,
	Export,
	ExportToFile,
	Expression,
	Expressions,
	ExtAttribsPage,
	ExtAttribsPerPage,
	ExtObjOids,
	Factor,
	FadeInObjects,
	FadedOut,
	Family,
	FastUpdate,
	Fdw,
	FileAssociated,
	FillColor,
	FilterOids,
	FilterTableTypes,
	Filter,
	FinalFunc,
	FiringType,
	FkColumn,
	FkConstr,
	FkDefs,
	FontSize,
	Font,
	ForegroundColor,
	ForeignKeys,
	FormatName,
	FromExp,
	FunctionType,
	Function,
	General,
	GenAlterCmds,
	Global,
	GrantOp,
	GridSize,
	Group,
	HandlerFunc,
	HandlesType,
	HasChanges,
	Hashes,
	HbaFile,
	Height,
	HideExtAttribs,
	HideRelName,
	HideTableTags,
	HighlightLines,
	HighlightOrder,
	HistoryMaxLength,
	Icon,
	Id,
	Identifier,
	IdentityType,
	IgnoredChars,
	Implicit,
	Import,
	Increment,
	IdentFile,
	IndexElement,
	IndexType,
	Index,
	Indexes,
	Info,
	InhColumn,
	InhColumns,
	Inherit,
	Inherited,
	InitialCond,
	InitialData,
	InitialExp,
	InlineFunc,
	InputFunc,
	InsEvent,
	InsertPriv,
	InternalLength,
	IntervalType,
	InvertRangeSelTrigger,
	IoCast,
	IsTemplate,
	IsPartitioned,
	Italic,
	JoinFunc,
	Label,
	LabelsPos,
	Landscape,
	Language,
	LastPosition,
	LastSysOid,
	LastValue,
	LastZoom,
	Layer,
	Layers,
	LeakProof,
	LeftType,
	Left,
	Length,
	Library,
	LikeType,
	Line,
	LineNumbersColor,
	LineNumbersBgColor,
	LineHighlightColor,
	ListenAddresses,
	Locale,
	LockerArc,
	LockerBody,
	Login,
	LookaheadChar,
	LowVerbosity,
	Materialized,
	MaxConnections,
	MaxObjCount,
	MaxValue,
	Maximized,
	MemberRoles,
	Member,
	Merges,
	Metadata,
	MinObjectOpacity,
	MinValue,
	Mode,
	ModelAuthor,
	NameLabel,
	NamePatterns,
	Name,
	Names,
	NegatorOp,
	NewName,
	NewTableName,
	NewIdentityType,
	NewVersion,
	NnColumn,
	NoInherit,
	None,
	NotExtObject,
	NotNull,
	NullsFirst,
	ObjSelection,
	ObjectId,
	ObjectFinder,
	ObjectType,
	Object,
	Objects,
	OidFilterOp,
	Oid,
	Oids,
	OldName,
	OldTableName,
	OldVersion,
	OpClass,
	OpClasses,
	OpFamily,
	OpListSize,
	OperatorFunc,
	Operator,
	Operators,
	Options,
	OriginalPk,
	OutputFunc,
	OwnerColumn,
	Owner,
	Pagination,
	PaperCustomSize,
	PaperMargin,
	PaperOrientation,
	PaperType,
	ParamIn,
	ParamOut,
	ParamVariadic,
	Parameter,
	Parameters,
	Parent,
	Parents,
	Parsable,
	PartialMatch,
	PartitionKey,
	PartitionedTable,
	PartitionBoundExpr,
	Partitioning,
	PartKeyCols,
	PartKeyColls,
	PartKeyOpCls,
	PartKeyExprs,
	Password,
	PasswordEncryption,
	Path,
	Patterns,
	PerRow,
	Permission,
	Permissive,
	PgModelerVersion,
	PgSqlBaseType,
	PgSqlVersion,
	Placeholder,
	Placeholders,
	PkColPattern,
	PkColumn,
	PkConstr,
	PkPattern,
	Points,
	Port,
	Portrait,
	PositionInfo,
	Position,
	Precision,
	Predicate,
	Preferred,
	PrependAtBod,
	PrependedSql,
	PrintGrid,
	PrintPgNum,
	PrivilegesGop,
	Privileges,
	ProtColumn,
	Protected,
	RangeAttribs,
	RangeType,
	RecentModels,
	Recent,
	RectVisible,
	Recursive,
	RecvFunc,
	ReducedForm,
	RefAlias,
	RefName,
	RefColumn,
	RefRoles,
	RefTable,
	RefTables,
	RefTableTag,
	RefType,
	Refer,
	Reference,
	ReferenceFk,
	ReferencesPriv,
	References,
	Referrers,
	RegularExp,
	RelationshipTabView,
	Relationship11,
	Relationship1n,
	RelationshipDep,
	RelationshipFk,
	RelationshipGen,
	RelationshipNn,
	RelationshipPart,
	Relationship,
	Rename,
	Replication,
	RestartSeq,
	RestrictionFunc,
	ReturnTable,
	ReturnType,
	ReturnsSetOf,
	Revoke,
	RightType,
	Right,
	RlsEnabled,
	RlsForced,
	RoleType,
	Role,
	Roles,
	RowAmount,
	Rules,
	SaveLastPosition,
	SaveRestoreGeometry,
	Schema,
	SchemaOid,
	SearchPath,
	SecurityType,
	SelectExp,
	SelectPriv,
	SelectObjects,
	SendFunc,
	Sequence,
	Server,
	ServerEncoding,
	ServerVersion,
	ServerPid,
	ServerProtocol,
	SetPerms,
	SharedObj,
	ShellTypes,
	ShowCanvasGrid,
	ShowPageDelimiters,
	ShowAttributesGrid,
	ShowSourcePane,
	ShowMainMenu,
	Signature,
	SimpleExp,
	SimplifiedObjCreation,
	SinglePkColumn,
	Size,
	Snippet,
	SortOp,
	SourceEditorApp,
	SourceEditorArgs,
	SourceType,
	SrcType,
	SpatialType,
	SpecialPkCols,
	SqlDisabled,
	SqlObject,
	SqlValidation,
	SqlTool,
	SrcColPattern,
	SrcColumns,
	SrcEncoding,
	SrcFkPattern,
	SrcLabel,
	SrcRequired,
	SrcTable,
	Srid,
	Ssl,
	SslCaFile,
	SslCertFile,
	SslCrlFile,
	SslKeyFile,
	Start,
	StateType,
	StorageParams,
	Storage,
	StrategyNum,
	Style,
	Styles,
	SubtypeDiffFunc,
	Subtype,
	Superuser,
	Symbol,
	TableBody,
	TableExtBody,
	TableName,
	TableObject,
	TableSchemaName,
	TableTitle,
	Table,
	TableType,
	Tablespace,
	Tag,
	TemplateDb,
	TemporaryPriv,
	Top,
	TpmodInFunc,
	TpmodOutFunc,
	TransitionFunc,
	TriggerFunc,
	TriggerPriv,
	Triggers,
	TruncEvent,
	TruncateCmds,
	TruncatePriv,
	Truncate,
	Trusted,
	TypeAttribute,
	TypeOid,
	Type,
	Types,
	TypeClass,
	UiLanguage,
	Underline,
	Unique,
	Unlogged,
	UnsetPerms,
	Unset,
	UpdAction,
	UpdEvent,
	UpdatePriv,
	UqColumn,
	UqConstr,
	UqPattern,
	UsagePriv,
	UseCurvedLines,
	UsePlaceholders,
	UseSignature,
	UseSorting,
	UseUniqueNames,
	UsingExp,
	ValidatorFunc,
	Validator,
	Validity,
	Validation,
	Value,
	Values,
	Variable,
	Variation,
	Version,
	ViewBody,
	ViewExtBody,
	ViewName,
	ViewSchemaName,
	ViewTitle,
	Visible,
	Widget,
	WidgetsGeometry,
	Width,
	Wildcard,
	WindowFunc,
	WithNoData,
	WithTimezone,
	WithoutOids,
	WordDelimiters,
	WordSeparators,
	WorkingDir,
	XPos,
	YPos,
	LastAnalyze,
	LastAutovacuum,
	LastVacuum,
	TuplesDel,
	TyplesUpd,
	TuplesIns;
}

#endif
